
clear
clear mata
clear matrix
clear results
set more off
set matsize 11000


*GLOBALS
***********************
*set path here
global path "C:\Users\raul\Dropbox\02. Research\03. CONTRACTS\05. REPLICATION"

do "$path\DOFILES\GLOBALS.do"




cd "$OUTPUT"

use "$DATA\ANALYSIS.dta", clear
 
****************************************************************************************************************************************************************
*** PREPARATIONS
****************************************************************************************************************************************************************

*PANEL A

* control mean
* C
reg C T_contract if STATE == 1

global control_S_C = _b[_cons]

reg C T_contract if STATE == 0 

global control_NS_C = _b[_cons]

reg C T_contract if MERCHANT_SHI==1

global control_SHI_C = _b[_cons]

reg C T_contract if MERCHANT_SHI!=1  & STATE==1 

global control_Other_C = _b[_cons]

* treatment effect
parmby "reghdfe C T_contract    if STATE==0, absorb($controls_contract $RB1 $RB2)", saving("$TEMP/MAIN_RESULT_COMPLEX_CHEAT_1.dta", replace)  level(95)
parmby "reghdfe C T_contract    if STATE==1, absorb($controls_contract $RB1 $RB2)", saving("$TEMP/MAIN_RESULT_COMPLEX_CHEAT_2.dta", replace)  level(95)
parmby "reghdfe C T_contract   if MERCHANT_SHI==1, absorb($RB1 $RB2  $controls_contract) ", saving("$TEMP/MAIN_RESULT_COMPLEX_CHEAT_3.dta", replace)  level(95)
parmby "reghdfe C T_contract    if MERCHANT_SHI!=1  & STATE==1, absorb($RB1 $RB2 $controls_contract)", saving("$TEMP/MAIN_RESULT_COMPLEX_CHEAT_B.dta", replace)  level(95)


*PANEL B
keep if B1==1

* control mean
* E
reg E T_contract if STATE == 1

global control_S_E = _b[_cons]

reg E T_contract if STATE == 0 

global control_NS_E = _b[_cons]

reg E T_contract if MERCHANT_SHI==1

global control_SHI_E = _b[_cons]

reg E T_contract if MERCHANT_SHI!=1  & STATE==1 

global control_Other_E = _b[_cons]

* treatment effect
parmby "reghdfe E T_contract  if STATE==0, absorb($RB1 $RB2 $controls_contract  )", saving("$TEMP/MAIN_RESULT_COMPLEX_1.dta", replace)  level(95)
parmby "reghdfe E T_contract    if STATE==1, absorb($RB1 $RB2 $controls_contract  )", saving("$TEMP/MAIN_RESULT_COMPLEX_2.dta", replace)  level(95)
parmby "reghdfe E T_contract    if MERCHANT_SHI==1, absorb($RB1 $RB2 $controls_contract  )", saving("$TEMP/MAIN_RESULT_COMPLEX_3.dta", replace)  level(95)
parmby "reghdfe E T_contract     if MERCHANT_SHI!=1  & STATE==1, absorb($RB1 $RB2 $controls_contract  )", saving("$TEMP/MAIN_RESULT_COMPLEX_B.dta", replace)  level(95)




****************************************************************************************************************************************************************
*** FIGURE A1, PANEL A
****************************************************************************************************************************************************************

use "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_1.dta", clear
replace estimate = $control_NS_C if parm == "_cons"
save "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_1.dta", replace

use "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_2.dta", clear
replace estimate = $control_S_C if parm == "_cons"
save "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_2.dta", replace

use "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_3.dta", clear
replace estimate = $control_SHI_C if parm == "_cons"
save "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_3.dta", replace

use "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_B.dta", clear
replace estimate = $control_Other_C if parm == "_cons"
save "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_B.dta", replace


use "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_1.dta", clear
append using "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_2.dta"
append using "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_3.dta"
append using "$TEMP/MAIN_RESULT_COMPLEX_CHEAT_B.dta"

keep if parm=="T_contract" | parm=="_cons" 
replace parmseq=1 if parm=="_cons" 
replace parmseq=2 if parm=="T_contract" 

gen x=ceil(_n/2)

***FIX LEVELS
*************

replace estimate=estimate+estimate[_n+1] if parm=="T_contract"

replace max95=max95+estimate[_n+1] if parm=="T_contract"
replace min95=min95+estimate[_n+1] if parm=="T_contract"
*min95=min95+min95[_n+1]
replace max95=. if parm=="_cons"
replace min95=. if parm=="_cons"

gsort x -parm

gen order = _n

twoway  (bar estimate order if parmseq==1 , barwidth(.6)) ///
	  (bar estimate order if parmseq==2, barwidth(.6)) ///
	 (rcap max95 min95 order, lwidth(.4) lcolor(black)), ///
     legend(off) ///
     xlabel( 1.5 "Disfavored m." 3.5 "State-favored m."  5.5 "S(Bashi) m." 7.5 "S(Other) m."  , noticks angle(0)) ///
     ylabel(, angle(0)) ///
	 xline(2.5 ,lcolor(black)  lwidth(.4)) ///
	 	xline(4.5 ,lcolor(black)  lwidth(.2) lpattern(dash)) ///
	xscale(range(0.5(1)6.5) ) ///
	scheme(s1mono) ///
	xtitle("  ") ytitle("Cheats")
    graph export "$OUTPUT/FIGURE_A1_PANEL_A.png",  replace width(1000) 

	
	
	
	
	
	
	
****************************************************************************************************************************************************************
*** FIGURE A1, PANEL B
****************************************************************************************************************************************************************


use "$TEMP/MAIN_RESULT_COMPLEX_1.dta", clear
replace estimate = $control_NS_E if parm == "_cons"
save "$TEMP/MAIN_RESULT_COMPLEX_1.dta", replace

use "$TEMP/MAIN_RESULT_COMPLEX_2.dta", clear
replace estimate = $control_S_E if parm == "_cons"
save "$TEMP/MAIN_RESULT_COMPLEX_2.dta", replace

use "$TEMP/MAIN_RESULT_COMPLEX_3.dta", clear
replace estimate = $control_SHI_E if parm == "_cons"
save "$TEMP/MAIN_RESULT_COMPLEX_3.dta", replace

use "$TEMP/MAIN_RESULT_COMPLEX_B.dta", clear
replace estimate = $control_Other_E if parm == "_cons"
save "$TEMP/MAIN_RESULT_COMPLEX_B.dta", replace


use "$TEMP/MAIN_RESULT_COMPLEX_1.dta", clear
append using "$TEMP/MAIN_RESULT_COMPLEX_2.dta"
append using "$TEMP/MAIN_RESULT_COMPLEX_3.dta"
append using "$TEMP/MAIN_RESULT_COMPLEX_B.dta"

keep if parm=="T_contract" | parm=="_cons" 
replace parmseq=1 if parm=="_cons" 
replace parmseq=2 if parm=="T_contract" 


gen x=ceil(_n/2)

***FIX LEVELS
*************

replace estimate=estimate+estimate[_n+1] if parm=="T_contract"

replace max95=max95+estimate[_n+1] if parm=="T_contract"
replace min95=min95+estimate[_n+1] if parm=="T_contract"

replace max95=. if parm=="_cons"
replace min95=. if parm=="_cons"

gsort x -parm

gen order = _n


twoway  (bar estimate order if parmseq==1 , barwidth(.6)) ///
	  (bar estimate order if parmseq==2, barwidth(.6)) ///
	 (rcap max95 min95 order, lwidth(.4) lcolor(black)), ///
     legend(off) ///
     xlabel( 1.5 "Disfavored m." 3.5 "State-favored m."  5.5 "S(Bashi) m." 7.5 "S(Other) m."  , noticks angle(0)) ///
     ylabel(0(.05).4, angle(0)) ///
	 xline(2.5 ,lcolor(black)  lwidth(.4)) ///
	 	xline(4.5 ,lcolor(black)  lwidth(.2) lpattern(dash)) ///
	xscale(range(0.5(1)6.5) ) ///
	scheme(s1mono) ///
	xtitle("  ") ytitle("Pays, conditional on initially accept", angle(0))
    graph export "$OUTPUT/FIGURE_A1_PANEL_B.png",  replace width(1000) 


	
	
