
clear
clear mata
clear matrix
clear results
set more off
set matsize 11000


*GLOBALS
***********************
*set path here
global path "C:\Users\raul\Dropbox\02. Research\03. CONTRACTS\05. REPLICATION"

do "$path/DOFILES/GLOBALS.do"

****************************************************************************************************************************************************************
***PROGRAM FOR TABLE 1
****************************************************************************************************************************************************************

include "$path/DOFILES/PROGRAM.do"

****************************************************************************************************************************************************************
***TABLE 1
****************************************************************************************************************************************************************

use "$DATA/ANALYSIS.dta" , clear

drop HOUSEHOLD HH_ETHNIC_*  

keep if timestamp!="" 


gen HOUSEHOLD=1
gen HOUSEHOLD_CONTRACT=HOUSEHOLD*T_contract
gen HOUSEHOLD_NOCONTRACT=HOUSEHOLD*(1-T_contract)


foreach var of varlist friends judic shame violence{
gen HOUSEHOLD_`var'=`var'
}

gen HOUSEHOLD_TUTSITRADER=HOUSEHOLD*Z_merchant_tutsi // non-state trader
gen HOUSEHOLD_STATETRADER=HOUSEHOLD*(1-Z_merchant_tutsi)

gen HOUSEHOLD_COETHNIC=HOUSEHOLD*COETHNIC
gen HOUSEHOLD_NCOETHNIC=HOUSEHOLD*(1-COETHNIC)



replace HOUSEHOLD_SIZE=. if HOUSEHOLD_SIZE>8


 gen FEMALE=(GENDER=="FEMME") & GENDER!=""


destring LANGUAGE, replace force

gen HH_ETHNIC_SHI=0 if LANGUAGE!=.

gen HH_ETHNIC_TUTSI=0 if LANGUAGE!=.

replace HH_ETHNIC_SHI=1 if LANGUAGE==27
replace HH_ETHNIC_TUTSI=1 if household_tutsi==1
*reminder that household tutsi is one if: LANGUAGE=="3" | LANGUAGE=="37" | LANGUAGE=="36" | LANGUAGE=="35" 
*these are the tutsi groups: Banyamulenge (s) 	3, Kinyabuisha	35, Kirwanda	36, Kinyarwanda	37
*see language code file


gen ETHNIC_STATE_NONSHI=1-HH_ETHNIC_TUTSI
replace ETHNIC_STATE_NONSHI=0 if HH_ETHNIC_SHI==1


global ethnic "TUTSI SHI"

foreach name of global ethnic{
rename HH_ETHNIC_`name' ETHNIC_`name'
}



gen AGE=2013-BIRTHYEAR



replace zANXIETY=-zANXIETY



*LABELS
*******

label var B0 "Buys, placebo "
label var B1 "Initially buys, sale on credit"
label var B2 "Buys, sale on credit"
label var R0 "Rejects the placebo offer, $\mathbm{I}_R(b^0_i)$"
label var R "Rejects the sale on credit, $\mathbm{I}_R(b_i)$"
label var E "Buys and pays in sale on credit, $\mathbm{I}_E(b_i)$"
label var C "Buys and defects in sale on credit,  $\mathbm{I}_C(b_i)$"

label var REPLACE_HH "Replacement household"

label var HOUSEHOLD_friends "Reputation loss"
label var HOUSEHOLD_judic "Legal prosecution"

label var HOUSEHOLD_shame "Psych. cost (shame)"
label var HOUSEHOLD_viol "Violence (public beating)"

label var HOUSEHOLD_SIZE "Household size"
label var AGE "Age"
label var FEMALE "Female"
label var EDUCATION_YEARS "Years of education"
label var ETHNIC_SHI "State-favored: \textit{Bashi}"
label var ETHNIC_TUTSI "Disfavored"
label var ETHNIC_STATE_NONSHI "State-favored: \textit{others}"

label var HOUSEHOLD "Buyers"
label var HOUSEHOLD_CONTRACT "$ \tilde{F}=1 $"
label var HOUSEHOLD_NOCONTRACT "$ \tilde{F}=0 $"


label var HOUSEHOLD_TUTSITRADER "$ D $"
label var HOUSEHOLD_STATETRADER "$ S $"
label var HOUSEHOLD_COETHNIC "$ S\{C\} $"
label var HOUSEHOLD_NCOETHNIC "$ S\{N\} $"

    
label var HH_OCCUPATION_PUBLIC "Occupation: public"


label var HH_WORKFOR_STATE   "Believes merchant works for government"
label var HH_WORKFOR_FOR   "Believes merchant works for foreigners"
label var HH_WORKFOR_FIRM   "Believes merchant works for firm"
label var HH_WORKFOR_NGO   "Believes merchant works for NGO"
label var HH_WORKFOR_UNI   "Believes merchant is a student"
label var zANXIETY   "Buyer's subjective well-being"
label var T_STATE   "Seen as state-favored"
label var T_COETHNIC   "Seen as co-ethnic"

 
label var POSSIBLE_PROSECUTION "Can contract lead to prosecution? (all)"
label var HH_BELIEF_OBJECTIVE_marketing "Objective is scoping a new market"
label var HH_BELIEF_OBJECTIVE_ethnic "Objective is research on ethnic groups"
label var HH_BELIEF_OBJECTIVE_trust "Objective is research on trustworthiness"


label var HH_CONTRACT_IMAGE_lowtrust "Contract signals low trust"
label var HH_CONTRACT_IMAGE_serious "Contract signals seriousness"
label var HH_CONTRACT_IMAGE_changegov "Contract signals state connection"
label var HH_CONTRACT_IMAGE_fraudulent "Contract is suspicious"



preserve
replace R0=. if household_tutsi==1
label var HOUSEHOLD "All"
cd "$OUTPUT"

sumstats HOUSEHOLD_SIZE AGE FEMALE EDUCATION_YEARS HH_OCCUPATION_PUBLIC ETHNIC_SHI ETHNIC_STATE_NONSHI ETHNIC_TUTSI REPLACE_HH   WEIRD    HH_CONTRACT_IMAGE_fraudulent HH_CONTRACT_IMAGE_changegov  HH_CONTRACT_IMAGE_serious HH_CONTRACT_IMAGE_lowtrust HH_BELIEF_OBJECTIVE_trust HH_BELIEF_OBJECTIVE_ethnic  HH_BELIEF_OBJECTIVE_marketing  HEARDOF   T_STATE  T_COETHNIC zANXIETY R0  R C E   HOUSEHOLD_friends HOUSEHOLD_shame HOUSEHOLD_viol HOUSEHOLD_judic POSSIBLE_PROSECUTION , filename(TABLE_1) gp2(  HOUSEHOLD_CONTRACT HOUSEHOLD_NOCONTRACT  HOUSEHOLD_STATETRADER HOUSEHOLD_TUTSITRADER HOUSEHOLD_NCOETHNIC HOUSEHOLD_COETHNIC )  gp1( HOUSEHOLD)   panellabel("1. Pre-Characteristics"; "2. Experiment design validity";  "3. Beliefs about merchant's identity";    "4. Ultimate choices";  "5. Beliefs about sanctions for cheating"; )  npanel(9 9 3 4  5) nosd  nofirsttitle noobs  firstrowobs("Observations")  nonumber  diffexplicitly(HOUSEHOLD_NOCONTRACT-HOUSEHOLD_CONTRACT  HOUSEHOLD_TUTSITRADER-HOUSEHOLD_STATETRADER HOUSEHOLD_COETHNIC-HOUSEHOLD_NCOETHNIC ) 
restore




****************************************************************************************************************************************************************
***TABLE A1 PANEL B
****************************************************************************************************************************************************************

label var HOUSEHOLD "All"
sumstats  HH_OCCUPATION_PUBLIC    HH_WORKFOR_FOR HH_WORKFOR_STATE HH_WORKFOR_UNI HH_WORKFOR_FIRM HH_WORKFOR_NGO  , filename(DESCRIPTIVE_STATISTICS_MERCHANTS_PANEL_B)  nosd  nofirsttitle noobs  firstrowobs("Observations")  nonumber  
