
clear
clear mata
clear matrix
clear results
set more off
set matsize 11000


*GLOBALS
***********************
*set path here
global path "C:\Users\raul\Dropbox\02. Research\03. CONTRACTS\05. REPLICATION"

do "$path\DOFILES\GLOBALS.do"



****************************************************************************************************************************************************************
***TABLE 4 - PANEL A PREPARATION
****************************************************************************************************************************************************************

cd "$OUTPUT"

use "$DATA\ANALYSIS.dta" , clear


sum choice if COETHNIC==0
local depvar = r(mean)
xi: mlogit choice COETHNIC  $controls_coethnic   if T_contract==0    , baseoutcome(1) rrr

*** MULTINOMIAL COEFFICIENT FOR E
local MULTINOMIAL_COEFF_BCOETHNIC_E=_b[E:COETHNIC]
display `MULTINOMIAL_COEFF_BSTATE_E'

local MULTINOMIAL_VAR_BCOETHNIC_E=_se[E:COETHNIC]
display `MULTINOMIAL_COEFF_BSTATE_E'


*** MULTINOMIAL COEFFICIENT FOR R
local MULTINOMIAL_COEFF_BCOETHNIC_R=_b[R:COETHNIC]
display `MULTINOMIAL_COEFF_BCOETHNIC_R'

local MULTINOMIAL_VAR_BCOETHNIC_R=_se[R:COETHNIC]
display `MULTINOMIAL_VAR_BCOETHNIC_R'




****************************************************************************************************************************************************************
***TABLE 4 - PANEL A
****************************************************************************************************************************************************************

****** DEPENDENT VARIABLE C

sum C if  COETHNIC==0 & T_contract==0 
local depvar = r(mean)

xi: reg  C COETHNIC      $controls_coethnic      if T_contract==0 
estimates store m2
outreg2 using  TABLE_4_PANEL_A, tex(frag) nocons replace ctitle(" $ C $ ") label keep( T_contract COETHNIC ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)  



****** DEPENDENT VARIABLE E

sum E if  COETHNIC==0 & T_contract==0 
local depvar = r(mean)

xi: reg  E COETHNIC       $controls_coethnic      if   T_contract==0 
outreg2 using  TABLE_4_PANEL_A, tex(frag) nocons append ctitle(" $ E $ ") label keep( T_contract COETHNIC ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar', Multinomial coeff., `MULTINOMIAL_COEFF_BCOETHNIC_E', Multinomial SE., `MULTINOMIAL_VAR_BCOETHNIC_E')  adec(2)  



****** DEPENDENT VARIABLE R

sum R if  COETHNIC==0 & T_contract==0 
local depvar = r(mean)

xi: reg  R COETHNIC       $controls_coethnic      if   T_contract==0 
outreg2 using  TABLE_4_PANEL_A, tex(frag) nocons append ctitle(" $ R $ ") label keep( T_contract COETHNIC ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar', Multinomial coeff., `MULTINOMIAL_COEFF_BCOETHNIC_R', Multinomial SE., `MULTINOMIAL_VAR_BCOETHNIC_R')  adec(2) 



****** DEPENDENT VARIABLE REPUTATION

sum friends  if STATE==1 & T_contract==0 & COETHNIC==0
local depvar = r(mean)
xi: reg  friends COETHNIC         $controls_coethnic          if STATE==1 & T_contract==0 
outreg2 using  TABLE_4_PANEL_A, tex(frag) nocons append ctitle(\textit{rep.}) label keep(  COETHNIC ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   



****** DEPENDENT VARIABLE SHAME

sum shame  if STATE==1 & T_contract==0 & COETHNIC==0
local depvar = r(mean)
xi: reg  shame COETHNIC         $controls_coethnic         if STATE==1 & T_contract==0 
outreg2 using  TABLE_4_PANEL_A, tex(frag) nocons append ctitle(\textit{shame}) label keep(  COETHNIC ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   



****** DEPENDENT VARIABLE VIOLENCE

sum violence  if STATE==1 & T_contract==0 & COETHNIC==0
local depvar = r(mean)
xi: reg  violence COETHNIC         $controls_coethnic         if STATE==1 & T_contract==0 
outreg2 using  TABLE_4_PANEL_A, tex(frag) nocons append ctitle(\textit{viol.}) label keep(  COETHNIC ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2) 





****** DEPENDENT VARIABLE PROSECUTION

sum judic  if STATE==1  & COETHNIC==0 & T_contract==0
local depvar = r(mean)

xi: reg  judic COETHNIC           $controls_coethnic          if STATE==1  & T_contract==0
estimates store m3
outreg2 using  TABLE_4_PANEL_A, tex(frag) nocons append ctitle(\textit{pros.}) label keep(  COETHNIC ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   


****** DEPENDENT VARIABLE POSSIBLE PROSECUTION

egen groupqs11=group(MERCHANT_name B2)
gen FAKECONTRACT=T_contract
gen FAKEB2=B2
gen FAKEB2FAKECONTRACT=FAKECONTRACT*FAKEB2
xi: reg  POSSIBLE_PROSECUTION i.MERCHANT_name*FAKEB2 i.MERCHANT_name i.MERCHANT_name*FAKECONTRACT
replace FAKECONTRACT=1
replace FAKEB2 = 1
predict PREDICT if e(sample)
drop FAKECONTRACT FAKEB2


sum PREDICT  if STATE==1  & COETHNIC==0   & badqs11_implementers!=1
local depvar = r(mean)

xi: reg  POSSIBLE_PROSECUTION COETHNIC     B2      $controls_coethnic   i.badqs*i.T_contract i.badqs*i.B2     if STATE==1   
estimates store m3
outreg2 using  TABLE_4_PANEL_A, tex(frag) nocons append ctitle(\textit{pros.}$^{*}$) label keep(  COETHNIC ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)    sortvar(COETHNIC CREDIT)






****************************************************************************************************************************************************************
***TABLE 4 - PANEL B PREPARATION
****************************************************************************************************************************************************************

cd "$OUTPUT"

use "$DATA\ANALYSIS.dta" , clear

replace equipe=2 if equipe==3
replace equipe=2 if equipe==4


xi: mlogit choice STATE  $controls_contract   i.$RB2 i.$RB0 if T_contract==0, baseoutcome(1)  rrr

*** MULTINOMIAL COEFFICIENT FOR E
local MULTINOMIAL_COEFF_BSTATE_E=_b[E:STATE]
display `MULTINOMIAL_COEFF_BSTATE_E'

local MULTINOMIAL_VAR_BSTATE_E=_se[E:STATE]
display `MULTINOMIAL_COEFF_BSTATE_E'


*** MULTINOMIAL COEFFICIENT FOR R
local MULTINOMIAL_COEFF_BSTATE_R=_b[R:STATE]
display `MULTINOMIAL_COEFF_BSTATE_E'

local MULTINOMIAL_VAR_BSTATE_R=_se[R:STATE]
display `MULTINOMIAL_COEFF_BSTATE_E'





****************************************************************************************************************************************************************
***TABLE 4 - PANEL B
****************************************************************************************************************************************************************


****** DEPENDENT VARIABLE C

sum C  if T_contract==0  & STATE==0 
local depvar = r(mean)

xi: reg  C STATE  $controls_contract   i.$RB0 i.$RB2    if T_contract==0   
estimates store m2, title(two)
outreg2 using  TABLE_4_PANEL_B, tex(frag) nocons replace ctitle("$ C $") label keep(    STATE ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)



****** DEPENDENT VARIABLE E

sum E  if T_contract==0  & STATE==0 
local depvar = r(mean)

xi: reg  E STATE  $controls_contract   i.$RB0 i.$RB2    if T_contract==0   
outreg2 using  TABLE_4_PANEL_B, tex(frag) nocons append ctitle("$ E $") label keep(    STATE ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar', Multinomial coeff., `MULTINOMIAL_COEFF_BSTATE_E', Multinomial SE., `MULTINOMIAL_VAR_BSTATE_E')  adec(2)



****** DEPENDENT VARIABLE R

xi: reg  R STATE  $controls_contract   i.$RB0 i.$RB2      if T_contract==0  
sum R  if T_contract==0  & STATE==0   & B0!=.
local depvar = r(mean) 
outreg2 using  TABLE_4_PANEL_B, tex(frag) nocons append ctitle("$ R $") label keep(STATE) dec(2)  noaster  nonote  addstat(Mean dep., `depvar', Multinomial coeff., `MULTINOMIAL_COEFF_BSTATE_R', Multinomial SE., `MULTINOMIAL_VAR_BSTATE_R')  adec(2)     



****** DEPENDENT VARIABLE REPUTATION

xi: reg  friends STATE    $controls_contract i.$RB0 i.$RB2         if T_contract==0
sum friends  if STATE==0 & T_contract==0
local depvar = r(mean)
*outreg2 using  TABLE_state, tex(frag) nocons append ctitle(\textit{rep.}) label keep(  STATE ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   
outreg2 using  TABLE_4_PANEL_B, tex(frag) nocons append ctitle(\textit{rep.}) label keep(  STATE ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   


****** DEPENDENT VARIABLE SHAME

xi: reg  shame STATE    $controls_contract i.$RB0 i.$RB2        if T_contract==0
sum shame  if STATE==0 & T_contract==0
local depvar = r(mean)
*outreg2 using  TABLE_state, tex(frag) nocons append ctitle( \textit{shame.}) label keep(  STATE ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   
outreg2 using  TABLE_4_PANEL_B, tex(frag) nocons append ctitle( \textit{shame.}) label keep(  STATE ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   


****** DEPENDENT VARIABLE VIOLENCE

xi: reg  viol STATE    $controls_contract i.$RB0 i.$RB2        if T_contract==0
sum viol  if STATE==0 & T_contract==0
local depvar = r(mean)
*outreg2 using  TABLE_state, tex(frag) nocons append ctitle( \textit{viol.}) label keep(  STATE ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   
outreg2 using  TABLE_4_PANEL_B, tex(frag) nocons append ctitle( \textit{viol.}) label keep(  STATE ) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   


****** DEPENDENT VARIABLE PROSECUTION

xi: reg  judic STATE    $controls_contract i.$RB0 i.$RB2        if T_contract==0
sum judic  if STATE==0 & T_contract==0
local depvar = r(mean)
*outreg2 using  TABLE_state, tex(frag) nocons append ctitle( \textit{pros.}) label keep(  STATE) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   
outreg2 using  TABLE_4_PANEL_B, tex(frag) nocons append ctitle( \textit{pros.}) label keep(  STATE) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   


****** DEPENDENT VARIABLE POSSIBLE PROSECUTION

egen groupqs11=group(MERCHANT_name B2)
gen FAKECONTRACT=T_contract
gen FAKEB2=B2
gen FAKEB2FAKECONTRACT=FAKECONTRACT*FAKEB2
xi: reg  POSSIBLE_PROSECUTION i.MERCHANT_name*FAKEB2 i.MERCHANT_name i.MERCHANT_name*FAKECONTRACT
replace FAKECONTRACT=1
replace FAKEB2 = 1
predict PREDICT if e(sample)

sum PREDICT  if STATE==0    
local depvar = r(mean)



xi: reg  POSSIBLE_PROSECUTION STATE  B2  $controls_contract i.$RB0 i.$RB2   i.badqs*B2 i.badqs i.badqs*T_contract     
outreg2 using  TABLE_4_PANEL_B, tex(frag) nocons append ctitle( \textit{pros$^{*}$.}) label keep(  STATE) dec(2)  noaster  nonote  addstat(Mean dep., `depvar')  adec(2)   

